<?php
/**
 * kanse_lab functions and definitions
 *
 * @package kanse_lab
 */


/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 640; /* pixels */

/*
 * Load Jetpack compatibility file.
 */
require( get_template_directory() . '/inc/jetpack.php' );

if ( ! function_exists( 'kanse_lab_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */

function kanse_lab_setup() {

	/**
	 * Custom template tags for this theme.
	 */
	require( get_template_directory() . '/inc/template-tags.php' );

	/**
	 * Custom functions that act independently of the theme templates
	 */
	require( get_template_directory() . '/inc/extras.php' );

	/**
	 * Customizer additions
	 */
	require( get_template_directory() . '/inc/customizer.php' );

	/**
	 * WordPress.com-specific functions and definitions
	 */
	//require( get_template_directory() . '/inc/wpcom.php' );

	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on kanse_lab, use a find and replace
	 * to change 'kanse_lab' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'kanse_lab', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * Enable support for Post Thumbnails on posts and pages
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	//add_theme_support( 'post-thumbnails' );

	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'kanse_lab' ),
'footermenu' => 'フッターメニュー',
	) );

	/**
	 * Enable support for Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );
}
endif; // kanse_lab_setup
add_action( 'after_setup_theme', 'kanse_lab_setup' );

/**
 * Setup the WordPress core custom background feature.
 *
 * Use add_theme_support to register support for WordPress 3.4+
 * as well as provide backward compatibility for WordPress 3.3
 * using feature detection of wp_get_theme() which was introduced
 * in WordPress 3.4.
 *
 * @todo Remove the 3.3 support when WordPress 3.6 is released.
 *
 * Hooks into the after_setup_theme action.
 */
function kanse_lab_register_custom_background() {
	$args = array(
		'default-color' => 'ffffff',
		'default-image' => '',
	);

	$args = apply_filters( 'kanse_lab_custom_background_args', $args );

	if ( function_exists( 'wp_get_theme' ) ) {
		add_theme_support( 'custom-background', $args );
	} else {
		define( 'BACKGROUND_COLOR', $args['default-color'] );
		if ( ! empty( $args['default-image'] ) )
			define( 'BACKGROUND_IMAGE', $args['default-image'] );
		add_custom_background();
	}
}
add_action( 'after_setup_theme', 'kanse_lab_register_custom_background' );

/**
 * Register widgetized area and update sidebar with default widgets
 */
function kanse_lab_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'kanse_lab' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'kanse_lab_widgets_init' );

/**
 * Enqueue scripts and styles
 */
function kanse_lab_scripts() {
	wp_enqueue_style( 'kanse_lab-style', get_stylesheet_uri() );


	wp_enqueue_script( 'kanse_lab-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'kanse_lab-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'kanse_lab-keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
	}
}
add_action( 'wp_enqueue_scripts', 'kanse_lab_scripts' );

/**
 * Implement the Custom Header feature
 */
require( get_template_directory() . '/inc/custom-header.php' );

//アイキャッチ画像
add_theme_support( 'post-thumbnails' );
set_post_thumbnail_size(150, 150, true ); //基本サイズ





//スキンファイルリストの並べ替え用の関数
function skin_files_comp($a, $b) {
  //優先度（priority）で比較する
  if ($a['priority'] == $b['priority']) {
      return 0;
  }
  return ($a['priority'] < $b['priority']) ? -1 : 1;
}
 
//スキンとなるファイルの取得
function get_skin_files(){
  $dir = dirname(__FILE__) . '/skins/';//skinsフォルダ内を検索
  $iterator = new RecursiveIteratorIterator(
    new RecursiveDirectoryIterator(
      $dir,
      FilesystemIterator::SKIP_DOTS
      |FilesystemIterator::KEY_AS_PATHNAME
      |FilesystemIterator::CURRENT_AS_FILEINFO
    ), RecursiveIteratorIterator::LEAVES_ONLY
  );

  $results = array();
  foreach($iterator as $pathname => $info){
    $pathname = str_replace('\\', '/', $pathname);
    $this_dir = str_replace('\\', '/', dirname(__FILE__));
    if (preg_match('/([a-zA-Z\-_]+).style\.css$/i', $pathname, $matches)){//フォルダ名の正規表現が[a-zA-Z\-_]+のとき
      $dir_name = $matches[1];
      $css = file_get_contents($pathname);//CSSファイルを開く
      if (preg_match('/Name: *(.+)/i', $css, $matches)) {//CSSファイルの中にName:の記述があるとき
        if (preg_match('/Priority: *(.+)/i', $css, $m)) {//優先度（順番）が設定されている場合は順番取得
          $priority = intval($m[1]);
        } else {
          $priority = 9999;
        }
        //返り値の設定
        $results[] = array(
          'name' => $matches[1],
          'dir' => $dir_name,
          'priority' => $priority,
          'path' => str_replace($this_dir, get_stylesheet_directory_uri(), $pathname),
        );
      }
    }
  }
  uasort($results, 'skin_files_comp');//スキンを優先度順に並び替え
  return $results;
}

