<?php
/**
 * Sample implementation of the Custom Header feature
 * http://codex.wordpress.org/Custom_Headers
 *
 * You can add an optional custom header image to header.php like so ...

	<?php $header_image = get_header_image();
	if ( ! empty( $header_image ) ) { ?>
		<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home">
			<img src="<?php header_image(); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="" />
		</a>
	<?php } // if ( ! empty( $header_image ) ) ?>

 *
 * @package kanse_lab_
 */

/**
 * Setup the WordPress core custom header feature.
 *
 * Use add_theme_support to register support for WordPress 3.4+
 * as well as provide backward compatibility for previous versions.
 * Use feature detection of wp_get_theme() which was introduced
 * in WordPress 3.4.
 *
 * @todo Rework this function to remove WordPress 3.4 support when WordPress 3.6 is released.
 *
 * @uses kanse_lab_header_style()
 * @uses kanse_lab_admin_header_style()
 * @uses kanse_lab_admin_header_image()
 *
 * @package _s
 */
function kanse_lab_custom_header_setup() {
	$args = array(
		'default-image'          => '',
		'default-text-color'     => '000',
		'width'                  => 1000,
		'height'                 => 250,
		'flex-height'            => true,
		'wp-head-callback'       => 'kanse_lab_header_style',
		'admin-head-callback'    => 'kanse_lab_admin_header_style',
		'admin-preview-callback' => 'kanse_lab_admin_header_image',
	);

//	$args = apply_filters( 'kanse_lab_custom_header_args', $args );

	if ( function_exists( 'wp_get_theme' ) ) {
		add_theme_support( 'custom-header', $args );
	} else {
		// Compat: Versions of WordPress prior to 3.4.
		define( 'HEADER_TEXTCOLOR',    $args['default-text-color'] );
		define( 'HEADER_IMAGE',        $args['default-image'] );
		define( 'HEADER_IMAGE_WIDTH',  $args['width'] );
		define( 'HEADER_IMAGE_HEIGHT', $args['height'] );
		add_custom_image_header( $args['wp-head-callback'], $args['admin-head-callback'], $args['admin-preview-callback'] );
	}
}
add_action( 'after_setup_theme', 'kanse_lab_custom_header_setup' );

/**
 * Shiv for get_custom_header().
 *
 * get_custom_header() was introduced to WordPress
 * in version 3.4. To provide backward compatibility
 * with previous versions, we will define our own version
 * of this function.
 *
 * @todo Remove this function when WordPress 3.6 is released.
 * @return stdClass All properties represent attributes of the curent header image.
 *
 * @package _s
 */

if ( ! function_exists( 'get_custom_header' ) ) {
	function get_custom_header() {
		return (object) array(
			'url'           => get_header_image(),
			'thumbnail_url' => get_header_image(),
			'width'         => HEADER_IMAGE_WIDTH,
			'height'        => HEADER_IMAGE_HEIGHT,
		);
	}
}

if ( ! function_exists( 'kanse_lab_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @see kanse_lab_custom_header_setup().
 */
function kanse_lab_header_style() {

	$header_image = get_header_image();
	$text_color   = get_header_textcolor();
	$che_hight =  get_option('hdh_txt' ); 
//var_dump( get_option('hdh_txt' ));
	$che_hight =$che_hight . 'px';
//echo $che_hight;
	$che_txt_s =  get_option('hdh_txt_s' ); 
//var_dump( get_option('hdh_txt_s' ));
	$che_txt_s =$che_txt_s . 'em';
//echo $che_txt_s;
	// If no custom options for text are set, let's bail.
	//if ( empty( $header_image ) && $text_color == get_theme_support( 'custom-header', 'default-text-color' ) )
	//	return;
	// If we get this far, we have custom styles.
	?>
	<style type="text/css" id="kanse_lab-header-css">
<?php
if ( $text_color != get_theme_support( 'custom-header', 'default-text-color' ) ){?>

	.site-title a{
		color: #<?php echo esc_attr( $text_color ); ?>;
	}
<?php
}

?>

@media screen and (min-width: 767px) {
	.site-title{
		font-size: <?php echo $che_txt_s; ?>;
	}
}
@media (max-width: 359px) {
	.site-title {
		font-size:: 1em;
	}
}

<?php 
if ( ! empty( $header_image ) ) :
?>
	.site-branding {
		background-image: url(<?php header_image(); ?>) ;
		background-position: top center;
		height:<?php echo $che_hight; ?> ;
		background-size: cover ;
	}

	@media (max-width: 767px) {
		.site-branding {
		background-size: 768px auto;
		height:auto;
		}
	}
	@media (max-width: 359px) {
		.site-branding {
		background-size: 360px auto;
		height:auto;
		}
	}

<?php
endif;

// Has the text been hidden?
if ( ! display_header_text() ) :
?>
	.site-title,
	.site-description {
	visibility:hidden;
			//position: absolute;
			//clip: rect(1px 1px 1px 1px); /* IE7 */
			//clip: rect(1px, 1px, 1px, 1px);
	}
<?php
	if ( empty( $header_image ) ) :
?>
		.site-branding .home-link {
			min-height: 0;
		}
<?php
	endif;

// If the user has set a custom color for the text, use that.
elseif ( $text_color != get_theme_support( 'custom-header', 'default-text-color' ) ) :
echo $text_color;
?>
	.site-title a:link  ,.site-title a:visited,
	.site-description {
		color: #<?php echo esc_attr( $text_color ); ?>;
	}
<?php endif; ?>
	</style>
<?php
}

endif; // kanse_lab_header_style

if ( ! function_exists( 'kanse_lab_admin_header_style' ) ) :
/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 *
 * @see kanse_lab_custom_header_setup().
 */
function kanse_lab_admin_header_style() {
?>
	<style type="text/css">
	.appearance_page_custom-header #headimg {
		border: none;
	}
	#headimg h1,
	#desc {
	}
	#headimg h1 {
	}
	#headimg h1 a {
	}
	#desc {
	}
	#headimg img {
	}
	</style>
<?php
}
endif; // kanse_lab_admin_header_style

if ( ! function_exists( 'kanse_lab_admin_header_image' ) ) :
/**
 * Custom header image markup displayed on the Appearance > Header admin panel.
 *
 * @see kanse_lab_custom_header_setup().
 */
function kanse_lab_admin_header_image() { ?>
	<div id="headimg">
		<?php
		if ( 'blank' == get_header_textcolor() || '' == get_header_textcolor() )
			$style = ' style="display:none;"';
		else
			$style = ' style="color:#' . get_header_textcolor() . ';"';
		?>
		<h1 class="displaying-header-text"><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
		<div class="displaying-header-text" id="desc"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></div>
	</div>
<?php }
endif; // kanse_lab_admin_header_image
