<?php
/**
 * kanse_lab Theme Customizer
 *
 * @package kanse_lab
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function kanse_lab_customize_preview_js() {
	wp_enqueue_script( 'kanse_lab_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130304', true );
}
add_action( 'customize_preview_init', 'kanse_lab_customize_preview_js' );


//テーマカスタマイザーの設定
add_action( 'customize_register', 'my_theme_customize_register' );
function my_theme_customize_register($wp_customize) {
  //スキン設定項目の追加
  $wp_customize->add_section( 'skin_section', array(
    'title'          =>'スキンの設定',
    'priority'       => 88,
  ));
  
  //スキンの種類
  $wp_customize->add_setting('skin_options[skin_file]', array(
     'default' => '',//デフォルト値
     'type'    => 'option',
  ));
  $skins = get_skin_files();//スキンファイル情報の取得
  $radio_items = array(
    '' => '選択しない（デフォルト）',//デフォルト値
  );
  foreach ($skins as $skin) {
    $radio_items += array($skin['path'] => $skin['name']);
  }
  $wp_customize->add_control( 'skin_file_radio', array(
    'settings' => 'skin_options[skin_file]',
    'label' =>'スキン選択（色指定などが優先）',
    'section' => 'skin_section',
    'type' => 'radio',
    'choices'    => $radio_items,
    'priority' => 10, //優先度（並び順）
  ));
}

//スキンファイルを取得
//スキンファイルを設定している場合はスタイルシート名（パス/style.css）を返す
//設定していない場合は偽（空文字）を返す
function get_skin_file(){
  $o = get_option('skin_options');
//var_dump($o);
  return $o['skin_file'];
}
/*
function hex2rgb ( $hex ) {
	if ( substr( $hex, 0, 1 ) == "#" ) $hex = substr( $hex, 1 ) ;
	if ( strlen( $hex ) == 3 ) $hex = substr( $hex, 0, 1 ) . substr( $hex, 0, 1 ) . substr( $hex, 1, 1 ) . substr( $hex, 1, 1 ) . substr( $hex, 2, 1 ) . substr( $hex, 2, 1 ) ;
	return array_map( "hexdec", [ substr( $hex, 0, 2 ), substr( $hex, 2, 2 ), substr( $hex, 4, 2 ) ] ) ;
}
*/



//テーマカスタマイザー
function kanse_lab_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	//ロゴ画像
	$wp_customize->add_section( 'header_logo_section' , array(
		'title' => 'ロゴ画像',
		'priority' => 30,
		'description' => 'サイトのロゴ設定'
	 ) );
	$wp_customize->add_setting( 'header_logo' ,array (
		'type'  => 'option',
		'sanitize_callback' => 'esc_url_raw'
		));
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'header_logo', array(
		'label' => 'ロゴ',
		'section' => 'header_logo_section',
		'settings' => 'header_logo',
	) ) );

	//フッター
	$wp_customize->add_section( 'foter_section' , array(
		'title' => 'フッター',
		'priority' => 30,
		'description' => 'サイトのフッター設定'
	 ) );
	$wp_customize->add_setting( 'footer_txt' ,array (
                'default'  => get_bloginfo( 'name' ),
		'type'  => 'option',
		));
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'foter_section', array(
		'label' => 'コピーライト文',
		'section' => 'foter_section',
		'settings' => 'footer_txt',
     		'type' => 'text',
	) ) );

//カスタムヘッダーサイズ
	$wp_customize->add_setting( 'hdh_txt' ,array (
                'default'  => '250',
		'type'  => 'option',
		));
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'title_tagline', array(
		'label' => 'ヘッダー高さ',
		'section' => 'title_tagline',
		'settings' => 'hdh_txt',
     		'type' => 'text',
	) ) );

	//ヘッダー背景色
	$wp_customize->add_setting( 'header_bg', array(
                'default'  => '#ffffff',
		'transport'   => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_bg', array(
		'label'        => 'ヘッダー背景色',
		'section'    => 'colors',
		'settings'   => 'header_bg',
	) ) );

//ヘッダータイトルサイズ
	$wp_customize->add_setting( 'hdh_txt_s' ,array (
                'default'  => '2',
		'type'  => 'option',
		));
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'title_fs', array(
		'label' => 'ヘッダータイトルサイズ',
		'section' => 'title_tagline',
		'settings' => 'hdh_txt_s',
     		'type' => 'text',
	) ) );




	//本文のリンク色
	$wp_customize->add_setting( 'link_color', array(
		'default'     => '#666666',
		'transport'   => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_color', array(
		'label'        => '本文のリンクの色',
		'section'    => 'colors',
		'settings'   => 'link_color',
	) ) );
	//キーカラー
	$wp_customize->add_setting( 'key_color', array(
		'default'     => '#00ffff',
		'transport'   => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'key_color', array(
		'label'        => 'キーカラー',
		'section'    => 'colors',
		'settings'   => 'key_color',
	) ) );
	//グローバルメニュー背景色
	$wp_customize->add_setting( 'header_menu_bg', array(
		'default'     => '#666666',
		'transport'   => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_menu_bg', array(
		'label'        => 'グローバルメニュー背景色',
		'section'    => 'colors',
		'settings'   => 'header_menu_bg',
	) ) );
	//グローバルメニュー文字色
	$wp_customize->add_setting( 'header_menu_link', array(
		'default'     => '#666666',
		'transport'   => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_menu_link', array(
		'label'        => 'グローバルメニュー文字の色',
		'section'    => 'colors',
		'settings'   => 'header_menu_link',
	) ) );
	//グローバルメニュー上下の線
/*
	$wp_customize->add_setting( 'header_menu_border', array(
		'default'     => '#d1d1d1',
		'transport'   => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_menu_border', array(
		'label'        => 'グローバルメニュー上下の線の色',
		'section'    => 'colors',
		'settings'   => 'header_menu_border',
	) ) );
*/
	//グローバルメニューの現在色
	$wp_customize->add_setting( 'navigation_current_vgcolor', array(
		'default'     => '#ffff00',
		'transport'   => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'navigation_current_vgcolor', array(
		'label'        => 'グローバルメニューの現在色',
		'section'    => 'colors',
		'settings'   => 'navigation_current_vgcolor',
	) ) );
	//グローバルメニューのホバー色
	$wp_customize->add_setting( 'navigation_hover_color', array(
		'default'     => '#ffff00',
		'transport'   => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'navigation_hover_color', array(
		'label'        => 'グローバルメニューのホバー色',
		'section'    => 'colors',
		'settings'   => 'navigation_hover_color',
	) ) );
	//コンテンツエリアの背景色
	$wp_customize->add_setting( 'contents_bg_color', array(
		'default'     => '#d1d1d1',
		'transport'   => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'contents_bg_color', array(
		'label'        => 'コンテンツエリアの背景色',
		'section'    => 'colors',
		'settings'   => 'contents_bg_color',
	) ) );
	//サイドバーの背景色
	$wp_customize->add_setting( 'sub_bg_color', array(
		'default'     => '#666666',
		'transport'   => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sub_bg_color', array(
		'label'        => 'サイドバーの背景色',
		'section'    => 'colors',
		'settings'   => 'sub_bg_color',
	) ) );

	//フッターの背景色
	$wp_customize->add_setting( 'footer_bg_color', array(
		'default'     => '#666666',
		'transport'   => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_bg_color', array(
		'label'        => 'フッターの背景色',
		'section'    => 'colors',
		'settings'   => 'footer_bg_color',
	) ) );

	//フッターの文字色
	$wp_customize->add_setting( 'footer_tx_color', array(
		'default'     => '#ffffff',
		'transport'   => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_tx_color', array(
		'label'        => 'フッターの文字色',
		'section'    => 'colors',
		'settings'   => 'footer_tx_color',
	) ) );

}
add_action( 'customize_register', 'kanse_lab_customize_register' );

//テーマカスタマイザーロゴ出力 ロゴイメージURLの取得
function get_the_logo_image_url(){
	$options =  get_option('header_logo');
	return $options;
}



//テーマカスタマイザーCSS出力
function kanse_lab_customize_css()
{
//echo get_theme_support( 'custom-header', 'default-text-color' )." "  ;
//echo get_header_textcolor();
	?>
	<style type="text/css">
<?php if(get_theme_mod('link_color','#666666') !='#666666'){ ?>
	a {
		color:<?php echo get_theme_mod('link_color','#666666'); ?>;
	}
<?php } ?>
<?php if(get_theme_mod('sub_link_color','#666666') !='#666666'){ ?>
	#breadcrumb.nav_menu li,#breadcrumb.nav_menu li a,#footer a {
		color:<?php echo get_theme_mod('sub_link_color','#666666'); ?>;
	}
<?php } ?>
<?php if(get_header_textcolor() !='000000'){ ?>
	.site_description ,.site_title a ,.site-title a:link  ,.site-title a:visited{
		color:#<?php echo get_header_textcolor();?>;
	}
<?php } ?>
<?php if(get_theme_mod('header_menu_bg','#666666') !='#666666'){ ?>
	.navigation-main { 
		background-color:<?php echo get_theme_mod('header_menu_bg','#666666'); ?>;
		/*border-top:1px solid <?php echo get_theme_mod('header_menu_border','#d1d1d1'); ?>;
		border-bottom:1px solid <?php echo get_theme_mod('header_menu_border','#d1d1d1'); ?>;*/
	}
<?php } ?>

@media screen and (max-width: 768px) {
	.navigation-main ul li:last-child {
		border-bottom: none;
	}
	.navigation-main li ul.sub-menu {
		background-color: transparent;
	}
<?php if(get_theme_mod('header_menu_link','#666666') !='#666666'){ ?>
	#breadcrumb,#breadcrumb li,#breadcrumb a {
		color:<?php echo get_theme_mod('header_menu_link','#666666'); ?>;
	}
<?php } ?>
}

<?php $header_bg = get_theme_mod( 'header_bg','#ffffff'); 
if (!empty($header_bg)){?>
	.home .wrapper.main {
		margin-top: 2rem;
	}
<?php } ?>
<?php
if ( ! display_header_text() ){?>
	#site_description {
	clip: rect(1px, 1px, 1px, 1px);
	position: absolute;
	}
<?php } ?>

<?php if(get_theme_mod('contents_bg_color','#d1d1d1') !='#d1d1d1'){ ?>
	.site-content,.page-header {
		background-color:<?php echo get_theme_mod('contents_bg_color','#d1d1d1');?>;
	}
<?php } ?>
<?php if(get_theme_mod('sub_bg_color','#666666') !='#666666'){ ?>
	.site-main .widget-area {
		background-color:<?php echo get_theme_mod('sub_bg_color','#666666');?>;
	}
<?php } ?>
<?php if(get_theme_mod('footer_tx_color','#ffffff') !='#ffffff'){ ?>
.site-info, .site-info a:link,.site-info a:visited{
		color:<?php echo get_theme_mod('footer_tx_color','#ffffff');?>;
	}
<?php } ?>
<?php if(get_theme_mod('footer_bg_color','#666666') !='#666666'){ ?>
	#colophon {
		background-color:<?php echo get_theme_mod('footer_bg_color','#666666');?>;
	}
<?php } ?>
<?php if(get_theme_mod('header_bg','#ffffff') !='#ffffff'){ ?>
	.site-branding {
		background-color:<?php echo get_theme_mod('header_bg','#ffffff');?>;//#FFFF00;
	}
<?php } ?>

.ui .menu {
background-color:#FFFF00;
}

<?php if(get_theme_mod('header_menu_link','#666666') !='#666666'){ ?>
.navigation-main a:link,.navigation-main a:visited {
		color:<?php echo get_theme_mod('header_menu_link','#666666'); ?>;
	}
<?php } ?>
/*.navigation-main {
//	background-color:#00FFFF;
			background-color:<?php echo get_theme_mod('header_menu_bg',''); ?>;
			border-top:1px solid <?php echo get_theme_mod('header_menu_border','#d1d1d1'); ?>;
			border-bottom:1px solid <?php echo get_theme_mod('header_menu_border','#d1d1d1'); ?>;
}
*/
<?php if(get_theme_mod('navigation_hover_color','#ffff00') !='#ffff00'){ ?>
	.navigation-main li :hover {
		background-color:<?php echo get_theme_mod('navigation_hover_color','#ffff00');?>;
	}
	.navigation-main li :active {
		background-color:<?php echo get_theme_mod('navigation_hover_color','#ffff00');?>;
	}
<?php } ?>
<?php if(get_theme_mod('navigation_current_vgcolor','#ffff00') !='#ffff00'){?>
	.navigation-main li.current-page-item a, .navigation-main li.current-menu-item a {
		background-color:<?php echo get_theme_mod('navigation_current_vgcolor','#ffff00');?>;
	}
<?php } ?>
<?php if(get_theme_mod('key_color','#00ffff') !='#00ffff'){ ?>
	.entry-title,.entry-title a {
		color :<?php echo get_theme_mod('key_color','#00ffff');?>;
	}
<?php } ?>
.site-title{
//<?php echo $che_txt_s; ?>
font-size: <?php echo $che_txt_s; ?>;
}

</style>
<?php 
}
add_action( 'wp_head', 'kanse_lab_customize_css');

//hex to rgb()
function hex2rgb($hex) {
    $hex = str_replace("#", "", $hex);
    if (strlen($hex) == 3) {
        $r = hexdec(substr($hex, 0, 1) . substr($hex, 0, 1));
        $g = hexdec(substr($hex, 1, 1) . substr($hex, 1, 1));
        $b = hexdec(substr($hex, 2, 1) . substr($hex, 2, 1));
    } else {
        $r = hexdec(substr($hex, 0, 2));
        $g = hexdec(substr($hex, 2, 2));
        $b = hexdec(substr($hex, 4, 2));
    }
    $rgb = array($r, $g, $b);
    //return implode(",", $rgb); // returns the rgb values separated by commas
    return $rgb; // returns an array with the rgb values
}



